{% extends 'base.html' %}
{% load django_bootstrap5 i18n %}

{% block content %}
<h1>{% translate "Password changed" %}</h1>
<p>{% translate "Your password has been changed. You should be able to log in now" %}:
{% url "login" as url_login %}
{% bootstrap_button _("Log in") button_class="btn-success" href=url_login %}
</p>
{% endblock %}
